@@ -123,7 +123,7 @@ class CloudPods:
             return None
 
     @enter_and_leave_function
-    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets,nic_num, vm_name, sku,count=1,reset_new_password=""):
+    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets, vm_name, sku,count=1,reset_new_password=""):
         if arch == "x86_64":
             bios="BIOS"
         else:
